{% extends 'studiogdo/pip/main_base.html' %}

{% load staticfiles %}
{% load studiogdo %}

{% block main %}
<div id="main" style="clear: both;">
    <h1 style="text-align: center;">
        {% block h1_title %}Portail Internet Personnalisé{% endblock %}
    </h1>
    <nav id="menupal">
        <img src="{% static 'studiogdo/pip/img/barre.png' %}"  alt="barre" id="barre_cwk">
        <br>
        {% block logo %}{% endblock %}
        <br>
        <img src="{% static 'studiogdo/pip/img/barre.png' %}"  alt="barre" id="barre_cwk">
        <br>
        <div style="margin-left: 120px; margin-bottom: 50px;">
        Réalisé par <a href="http://www.coworks.pro" target="_blank">CoWorks</a>
        </div>
        <div id="menu_level1"></div>
    </nav>
</div>
{% endblock main %}

