// Generated by CoffeeScript 1.8.0
(function() {
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  define(["list/listAndSelection"], function(List) {
    var ListOrSelection;
    return ListOrSelection = (function(_super) {
      __extends(ListOrSelection, _super);

      function ListOrSelection() {
        this.closeSelected = __bind(this.closeSelected, this);
        this.drawSelectedCallback = __bind(this.drawSelectedCallback, this);
        return ListOrSelection.__super__.constructor.apply(this, arguments);
      }

      ListOrSelection.prototype.drawSelectedCallback = function() {
        this.hideList();
        return ListOrSelection.__super__.drawSelectedCallback.apply(this, arguments);
      };

      ListOrSelection.prototype.closeSelected = function() {
        ListOrSelection.__super__.closeSelected.apply(this, arguments);
        this.showList();
        return this.hideSelected();
      };

      return ListOrSelection;

    })(List);
  });

}).call(this);

//# sourceMappingURL=listOrSelection.js.map
