{% extends 'studiogdo/pip/main_base.html' %}

{% load studiogdo %}

{% block main_content %}
    <form method="post" enctype="multipart/form-data" action="" data-apath="{{data_path|b64encode}}" class="details-form">
    {% csrf_token %}
        <div class="row">
            <div class="col-sm-2">
                <h4><strong>{{titre}}</strong></h4>
            </div>
            <div class="col-sm-10">
                {% block buttons %}{% endblock buttons %}
            </div>
        </div>
        <div class="row">
            <div class="col-sm-12">
                {% skel skel.0 data_path %}
            </div>
        </div>
    </form>
{% endblock main_content %}

{% block coffee %}
require(['pip/form'], function(Form) {
    new Form("{{ data_path|b64encode }}")
});
require(['pip/list'], function(List) {
    new List()
});
{% endblock coffee %}
