// Generated by CoffeeScript 1.8.0
(function() {
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };

  define(function() {
    var Login;
    Login = (function() {
      function Login() {
        this.passwdKeyPress = __bind(this.passwdKeyPress, this);
        $("#password").on("keypress", this.passwdKeyPress);
      }

      Login.prototype.passwdKeyPress = function(evt) {
        var maj, shift_status, which;
        which = evt.which;
        shift_status = evt.shiftKey;
        maj = ((which >= 65 && which <= 90) && !shift_status) || ((which >= 97 && which <= 122) && shift_status);
        if (maj) {
          $('#password').closest('.form-group').addClass('has-warning');
          return $("#alertMaj").show();
        } else {
          $('#password').closest('.form-group').removeClass('has-warning');
          return $("#alertMaj").hide();
        }
      };

      return Login;

    })();
    return new Login;
  });

}).call(this);

//# sourceMappingURL=login.js.map
